.. -*-restructuredtext-*-

.. image:: https://travis-ci.org/ubernostrum/django-registration.svg?branch=master
    :target: https://travis-ci.org/ubernostrum/django-registration

This is a fairly simple user-registration application for Django,
designed to make allowing user signups as painless as possible. It
requires a functional installation of Django 1.7 or newer, but has no
other dependencies.

Full documentation is `available online
<https://django-registration.readthedocs.org/>`_.